@@ -6,7 +6,7 @@ use Moose;
 # want to do an "info" call on every single file in every single commit
 # just to find out what it is.
 
-with 'VCI::Abstract::Committable', 'VCI::VCS::Svn::Committable';
+extends 'VCI::VCS::Svn::File', 'VCI::VCS::Svn::Directory';
 
 __PACKAGE__->meta->make_immutable;
 
